From b09eb06dae77be27e56d1573de0de7d393950ce5 Mon Sep 17 00:00:00 2001
From: Evan Prodromou <evan@controlyourself.ca>
Date: Thu, 12 Feb 2009 16:04:43 -0500
Subject: Revert "Just discovered the PEAR_Error handling function in
 index.php. Duh."

This reverts commit 616bdd43a921b2554d21b80af28ddb0fb6cb3c16.

Kind of a long hard way to deal with a simple situation, so I'd prefer
to just use the global handler.
---
 lib/action.php | 31 +++++++++++++------------------
 1 file changed, 13 insertions(+), 18 deletions(-)

(limited to 'lib/action.php')

-- 
cgit v1.2.3-54-g00ecf


From 3b5fd8fb6bbfa95efe3294ea77ae809dab071f99 Mon Sep 17 00:00:00 2001
From: Evan Prodromou <evan@controlyourself.ca>
Date: Thu, 12 Feb 2009 16:05:37 -0500
Subject: Revert "Code to handle PEAR_Errors raised by DB_DataObject that are
 bubbling"

This reverts commit 9f035e2847e0d119ca3d70e02df6f4fa73ca64c3.

It's a lot of complicated stuff, and the global handler probably does
fine.
---
 actions/emailsettings.php | 22 ----------------------
 actions/register.php      | 23 +----------------------
 lib/action.php            | 26 --------------------------
 3 files changed, 1 insertion(+), 70 deletions(-)

(limited to 'lib/action.php')

diff --git a/actions/emailsettings.php b/actions/emailsettings.php
index c6c983453..b84acb214 100644
--- a/actions/emailsettings.php
+++ b/actions/emailsettings.php
@@ -487,26 +487,4 @@ class EmailsettingsAction extends AccountSettingsAction
             return $other->id != $user->id;
         }
     }
-    
-    /**
-     * Check old fashioned PEAR_Error msgs coming from DB_DataObject
-     *
-     * In this case email don't exist in the DB yet, so DB_DataObject
-     * throws an error. Overrided from Action.
-     *
-     * @param PEAR_Error 
-     *
-     * @return nothing
-     */
-     
-    function checkDB_DataObjectError($error) {
-        if ($error->getCode() == DB_DATAOBJECT_ERROR_NODATA) {
-           
-           // Do nothing.
-                      
-        } else {
-            parent::checkDB_DataObjectError($error);
-        }
-    }
-    
 }
diff --git a/actions/register.php b/actions/register.php
index 853bd0cf6..5d7a8ce69 100644
--- a/actions/register.php
+++ b/actions/register.php
@@ -223,31 +223,10 @@ class RegisterAction extends Action
      */
 
     function nicknameExists($nickname)
-    {        
+    {
         $user = User::staticGet('nickname', $nickname);
         return ($user !== false);
     }
-        
-    /**
-     * Check old fashioned PEAR_Error msgs coming from DB_DataObject
-     *
-     * In this case nickname and email don't exist in the DB yet,
-     * so DB_DataObject throws an error. Overrided from Action.
-     *
-     * @param PEAR_Error 
-     *
-     * @return nothing
-     */
-     
-    function checkDB_DataObjectError($error) {
-        if ($error->getCode() == DB_DATAOBJECT_ERROR_NODATA) {
-           
-           // Do nothing.
-                      
-        } else {
-            parent::checkDB_DataObjectError($error);
-        }
-    }
 
     /**
      * Does the given email address already exist?
diff --git a/lib/action.php b/lib/action.php
index e3a8ef62c..bd38bf79c 100644
--- a/lib/action.php
+++ b/lib/action.php
@@ -82,17 +82,6 @@ class Action extends HTMLOutputter // lawsuit
      */
     function prepare($argarray)
     {
-        // This is for checking PEAR_Errors raised by DB_DataObject.
-        // Setting this to PEAR_ERROR_CALLBACK because setting
-        // to PEAR_ERROR_EXCEPTION does't work to allow PEAR_Errors
-        // to be handled as PHP5 exceptions, and PEAR_ERROR_RETURN
-        // does not cause DB_DataObject to actually return PEAR_Errors
-        // that can be checked with PEAR::isError() -- instead
-        // they just disappear into the ether, and can only be checked for
-        // after the fact. -- Zach    
-        PEAR::setErrorHandling(PEAR_ERROR_CALLBACK, 
-               array($this, "checkDB_DataObjectError"));
-        
         $this->args =& common_copy_args($argarray);
         return true;
     }
@@ -855,21 +844,6 @@ class Action extends HTMLOutputter // lawsuit
         throw new ClientException($msg, $code);
     }
 
-    /**
-     * Check old fashioned PEAR_Error msgs coming from DB_DataObject
-     *
-     * Logs the DB_DataObject error. Override to do something else.
-     * 
-     * @param PEAR_Error 
-     *
-     * @return nothing
-     */
-     
-    function checkDB_DataObjectError($error) {
-        common_log(LOG_ERR, $error->getMessage());
-            // XXX: throw an exception here? --Zach
-    }
-    
     /**
      * Returns the current URL
      *
diff --git a/lib/action.php b/lib/action.php
index 926fe93fb..e3a8ef62c 100644
--- a/lib/action.php
+++ b/lib/action.php
@@ -82,10 +82,16 @@ class Action extends HTMLOutputter // lawsuit
      */
     function prepare($argarray)
     {
-     
-        // For PEAR_Errors comming from DB_DataObject
+        // This is for checking PEAR_Errors raised by DB_DataObject.
+        // Setting this to PEAR_ERROR_CALLBACK because setting
+        // to PEAR_ERROR_EXCEPTION does't work to allow PEAR_Errors
+        // to be handled as PHP5 exceptions, and PEAR_ERROR_RETURN
+        // does not cause DB_DataObject to actually return PEAR_Errors
+        // that can be checked with PEAR::isError() -- instead
+        // they just disappear into the ether, and can only be checked for
+        // after the fact. -- Zach    
         PEAR::setErrorHandling(PEAR_ERROR_CALLBACK, 
-               array($this, "handleError"));
+               array($this, "checkDB_DataObjectError"));
         
         $this->args =& common_copy_args($argarray);
         return true;
@@ -850,7 +856,7 @@ class Action extends HTMLOutputter // lawsuit
     }
 
     /**
      * Handle old fashioned PEAR_Error msgs coming from DB_DataObject
      *
      * Logs the DB_DataObject error. Override to do something else.
      * 
@@ -859,20 +865,9 @@ class Action extends HTMLOutputter // lawsuit
      * @return nothing
      */
      
-    function handleError($error) {
-                        
-        common_log(LOG_ERR, "PEAR error: " . $error->getMessage());
-         $msg = sprintf(_('The database for %s isn\'t responding correctly, '.
-                          'so the site won\'t work properly. '.
-                          'The site admins probably know about the problem, '.
-                          'but you can contact them at %s to make sure. '.
-                          'Otherwise, wait a few minutes and try again.'),
-                        common_config('site', 'name'),
-                        common_config('site', 'email'));
-
-         $dac = new DBErrorAction($msg, 500);
-         $dac->showPage();
-         exit(-1);            
+    function checkDB_DataObjectError($error) {
+        common_log(LOG_ERR, $error->getMessage());
+            // XXX: throw an exception here? --Zach
     }
     
     /**
@@ -850,7 +856,7 @@ class Action extends HTMLOutputter // lawsuit
 
     /**
-     * Handle old fashioned PEAR_Error msgs coming from DB_DataObject
+     * Check old fashioned PEAR_Error msgs coming from DB_DataObject
      *
      * Logs the DB_DataObject error. Override to do something else.
-- 
cgit v1.2.3-54-g00ecf